@@ -1,19 +1,16 @@
-import subprocess
-import os
-import tempfile
-import json
-import json
-import traceback
-import logging
-import shutil
-import boto3
 import contextlib
-from datetime import datetime
-from uuid import uuid4
-
+import json
+import logging
+import os
+import shutil
+import subprocess
+import tempfile
 from urllib.request import Request, urlopen
+from uuid import uuid4
 from zipfile import ZipFile
 
+import boto3
+
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
@@ -21,6 +18,7 @@ cloudfront = boto3.client('cloudfront')
 
 CFN_SUCCESS = "SUCCESS"
 CFN_FAILED = "FAILED"
+ENV_KEY_MOUNT_PATH = "MOUNT_PATH"
 
 def handler(event, context):
 
@@ -117,43 +115,49 @@ def handler(event, context):
 #---------------------------------------------------------------------------------------------------
 # populate all files from s3_source_zips to a destination bucket
 def s3_deploy(s3_source_zips, s3_dest, user_metadata, system_metadata, prune, exclude, include):
-    # create a temporary working directory
-    workdir=tempfile.mkdtemp()
+    # create a temporary working directory in /tmp or if enabled an attached efs volume
+    if ENV_KEY_MOUNT_PATH in os.environ:
+        workdir = os.getenv(ENV_KEY_MOUNT_PATH) + "/" + str(uuid4())
+        os.mkdir(workdir)
+    else:
+        workdir = tempfile.mkdtemp()
+
     logger.info("| workdir: %s" % workdir)
 
     # create a directory into which we extract the contents of the zip file
     contents_dir=os.path.join(workdir, 'contents')
     os.mkdir(contents_dir)
 
-    # download the archive from the source and extract to "contents"
-    for s3_source_zip in s3_source_zips:
-        archive=os.path.join(workdir, str(uuid4()))
-        logger.info("archive: %s" % archive)
-        aws_command("s3", "cp", s3_source_zip, archive)
-        logger.info("| extracting archive to: %s\n" % contents_dir)
-        with ZipFile(archive, "r") as zip:
-          zip.extractall(contents_dir)
+    try:
+        # download the archive from the source and extract to "contents"
+        for s3_source_zip in s3_source_zips:
+            archive=os.path.join(workdir, str(uuid4()))
+            logger.info("archive: %s" % archive)
+            aws_command("s3", "cp", s3_source_zip, archive)
+            logger.info("| extracting archive to: %s\n" % contents_dir)
+            with ZipFile(archive, "r") as zip:
+              zip.extractall(contents_dir)
 
-    # sync from "contents" to destination
+        # sync from "contents" to destination
 
-    s3_command = ["s3", "sync"]
+        s3_command = ["s3", "sync"]
 
-    if prune:
-      s3_command.append("--delete")
+        if prune:
+          s3_command.append("--delete")
 
-    if exclude:
-      for filter in exclude:
-        s3_command.extend(["--exclude", filter])
+        if exclude:
+          for filter in exclude:
+            s3_command.extend(["--exclude", filter])
 
-    if include:
-      for filter in include:
-        s3_command.extend(["--include", filter])
+        if include:
+          for filter in include:
+            s3_command.extend(["--include", filter])
 
-    s3_command.extend([contents_dir, s3_dest])
-    s3_command.extend(create_metadata_args(user_metadata, system_metadata))
-    aws_command(*s3_command)
-
-    shutil.rmtree(workdir)
+        s3_command.extend([contents_dir, s3_dest])
+        s3_command.extend(create_metadata_args(user_metadata, system_metadata))
+        aws_command(*s3_command)
+    finally:
+        shutil.rmtree(workdir)
 
 #---------------------------------------------------------------------------------------------------
 # invalidate files in the CloudFront distribution edge caches
